@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class Libvirt
+  module Libvirt
+    class Compute
       class Real
         def create_volume(pool_name, xml)
           client.lookup_storage_pool_by_name(pool_name).create_vol_xml(xml)
